@@ -2,8 +2,9 @@
   v <- utils::packageVersion(pkgname)
   b <- utils::packageDate(pkgname)
   
-  foo <- paste0(" ", pkgname, " (Version ", v, ", Build Date: ", if (!anyNA(b)) format(b, "%F"), ")")
+  foo <- sprintf(" %s (Version %s, Build Date: %s)",
+                 pkgname, v, if (anyNA(b)) "unknown" else format(b, "%F"))
   packageStartupMessage(foo)
 }
 
-globalVariables(c("density", "count"))
\ No newline at end of file
+globalVariables(c("density", "count"))
